@@ -50,7 +50,7 @@ print_mimetypes (void)
 {
 	guint i;
 
-	for (i =0; i < G_N_ELEMENTS (audio_mime_types); i++) {
+	for (i =0; audio_mime_types[i] != NULL; i++) {
 		g_print ("%s\n", audio_mime_types[i]);
 	}
 }
